"""
This type stub file was generated by pyright.
"""

"""
Nothing here but dictionaries for generating LinearSegmentedColormaps,
and a dictionary of these dictionaries.

Documentation for each is in pyplot.colormaps().  Please update this
with the purpose and type of your colormap if you add data for one here.
"""
_binary_data = ...
_autumn_data = ...
_bone_data = ...
_cool_data = ...
_copper_data = ...
_flag_data = ...
_prism_data = ...
def cubehelix(gamma=..., s=..., r=..., h=...): # -> dict[str, partial[Unknown]]:
    """
    Return custom data dictionary of (r, g, b) conversion functions, which can
    be used with :func:`register_cmap`, for the cubehelix color scheme.

    Unlike most other color schemes cubehelix was designed by D.A. Green to
    be monotonically increasing in terms of perceived brightness.
    Also, when printed on a black and white postscript printer, the scheme
    results in a greyscale with monotonically increasing brightness.
    This color scheme is named cubehelix because the (r, g, b) values produced
    can be visualised as a squashed helix around the diagonal in the
    (r, g, b) color cube.

    For a unit color cube (i.e. 3D coordinates for (r, g, b) each in the
    range 0 to 1) the color scheme starts at (r, g, b) = (0, 0, 0), i.e. black,
    and finishes at (r, g, b) = (1, 1, 1), i.e. white. For some fraction *x*,
    between 0 and 1, the color is the corresponding grey value at that
    fraction along the black to white diagonal (x, x, x) plus a color
    element. This color element is calculated in a plane of constant
    perceived intensity and controlled by the following parameters.

    Parameters
    ----------
    gamma : float, default: 1
        Gamma factor emphasizing either low intensity values (gamma < 1), or
        high intensity values (gamma > 1).
    s : float, default: 0.5 (purple)
        The starting color.
    r : float, default: -1.5
        The number of r, g, b rotations in color that are made from the start
        to the end of the color scheme.  The default of -1.5 corresponds to ->
        B -> G -> R -> B.
    h : float, default: 1
        The hue, i.e. how saturated the colors are. If this parameter is zero
        then the color scheme is purely a greyscale.
    """
    ...

_cubehelix_data = ...
_bwr_data = ...
_brg_data = ...
gfunc = ...
_gnuplot_data = ...
_gnuplot2_data = ...
_ocean_data = ...
_afmhot_data = ...
_rainbow_data = ...
_seismic_data = ...
_terrain_data = ...
_gray_data = ...
_hot_data = ...
_hsv_data = ...
_jet_data = ...
_pink_data = ...
_spring_data = ...
_summer_data = ...
_winter_data = ...
_nipy_spectral_data = ...
_Blues_data = ...
_BrBG_data = ...
_BuGn_data = ...
_BuPu_data = ...
_GnBu_data = ...
_Greens_data = ...
_Greys_data = ...
_Oranges_data = ...
_OrRd_data = ...
_PiYG_data = ...
_PRGn_data = ...
_PuBu_data = ...
_PuBuGn_data = ...
_PuOr_data = ...
_PuRd_data = ...
_Purples_data = ...
_RdBu_data = ...
_RdGy_data = ...
_RdPu_data = ...
_RdYlBu_data = ...
_RdYlGn_data = ...
_Reds_data = ...
_Spectral_data = ...
_YlGn_data = ...
_YlGnBu_data = ...
_YlOrBr_data = ...
_YlOrRd_data = ...
_Accent_data = ...
_Dark2_data = ...
_Paired_data = ...
_Pastel1_data = ...
_Pastel2_data = ...
_Set1_data = ...
_Set2_data = ...
_Set3_data = ...
_gist_earth_data = ...
_gist_gray_data = ...
_gist_heat_data = ...
_gist_ncar_data = ...
_gist_rainbow_data = ...
_gist_stern_data = ...
_gist_yarg_data = ...
_coolwarm_data = ...
_CMRmap_data = ...
_wistia_data = ...
_tab10_data = ...
_tab20_data = ...
_tab20b_data = ...
_tab20c_data = ...
datad = ...
